summaryrefslogtreecommitdiffstats
path: root/tests/stress/src/com
diff options
context:
space:
mode:
authorChirayu Desai <chirayudesai1@gmail.com>2012-08-02 12:23:05 +0530
committerChirayu Desai <chirayudesai1@gmail.com>2012-08-02 12:32:27 +0530
commit4ca067e55ce5c0e756bce8cb11496589b8ab3ea0 (patch)
tree720e310c94e1f32cc50893461147e6eb18c4ae6d /tests/stress/src/com
parent262635a1a417326a4db253e0f06b9056670a8d33 (diff)
downloadpackages_apps_trebuchet-4ca067e55ce5c0e756bce8cb11496589b8ab3ea0.tar.gz
packages_apps_trebuchet-4ca067e55ce5c0e756bce8cb11496589b8ab3ea0.tar.bz2
packages_apps_trebuchet-4ca067e55ce5c0e756bce8cb11496589b8ab3ea0.zip
Rename Launcher to Trebuchet
Launcher2 is now Trebuchet application_name removed from localized strings and made un-translatable com.android.launcher is now com.cyanogenmod.trebuchet
Diffstat (limited to 'tests/stress/src/com')
-rw-r--r--tests/stress/src/com/cyanogenmod/trebuchet/stress/LauncherRotationStressTest.java (renamed from tests/stress/src/com/android/launcher2/stress/LauncherRotationStressTest.java)8
1 files changed, 4 insertions, 4 deletions
diff --git a/tests/stress/src/com/android/launcher2/stress/LauncherRotationStressTest.java b/tests/stress/src/com/cyanogenmod/trebuchet/stress/LauncherRotationStressTest.java
index d21fd53b..e2ced63a 100644
--- a/tests/stress/src/com/android/launcher2/stress/LauncherRotationStressTest.java
+++ b/tests/stress/src/com/cyanogenmod/trebuchet/stress/LauncherRotationStressTest.java
@@ -14,10 +14,10 @@
* limitations under the License.
*/
-package com.android.launcher2.stress;
+package com.cyanogenmod.trebuchet.stress;
-import com.android.launcher2.Launcher;
+import com.cyanogenmod.trebuchet.Launcher;
import android.content.pm.ActivityInfo;
import android.os.SystemClock;
@@ -26,13 +26,13 @@ import android.test.RepetitiveTest;
import android.util.Log;
/**
* Run rotation stress test using Launcher2 for 50 iterations.
*/
public class LauncherRotationStressTest extends ActivityInstrumentationTestCase2<Launcher> {
private static final int NUM_ITERATIONS = 50;
private static final int WAIT_TIME_MS = 500;
- private static final String LOG_TAG = "LauncherRotationStressTest";
+ private static final String LOG_TAG = "TrebuchetRotationStressTest";
public LauncherRotationStressTest() {
super(Launcher.class);
@@ -26,13 +26,13 @@ import android.test.RepetitiveTest;
import android.util.Log;
/**
- * Run rotation stress test using Launcher2 for 50 iterations.
+ * Run rotation stress test using Trebuchet for 50 iterations.
*/
public class LauncherRotationStressTest extends ActivityInstrumentationTestCase2<Launcher> {